@@ -144,7 +144,7 @@ def plainSupervised(path,pathUnlabelled,learn,th):
         shutil.copytree(path, newPath)
     else:
         raise Exception("The path "+newPath+" already exists")
-    for image in tqdm(images):
+    for image in tqdm(images,position=0, leave=True):
         pn=learn.predict(image)
         if pn[2][pn[2].argmax()]>th:
             shutil.copyfile(image,newPath+os.sep+'train'+os.sep+pn[0]+os.sep+pn[0]+'_'+image.split(os.sep)[-1])
